@@ -3,14 +3,15 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
 
-import typing
-
 """
 .. code-block:: python
 
     @property
     Lorentz.Et2(self)
 """
+from __future__ import annotations
+
+import typing
 
 import numpy
 
@@ -118,7 +119,7 @@ def dispatch(v: typing.Any) -> typing.Any:
                 v.lib,
                 *v.azimuthal.elements,
                 *v.longitudinal.elements,
-                *v.temporal.elements
+                *v.temporal.elements,
             ),
             returns,
             1,
