@@ -3,13 +3,14 @@
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/vector for details.
 
-import typing
-
 """
 .. code-block:: python
 
     Lorentz.boostZ(self, beta=...)
 """
+from __future__ import annotations
+
+import typing
 
 import numpy
 
@@ -221,7 +222,7 @@ def dispatch(beta: typing.Any, v: typing.Any) -> typing.Any:
                 beta,
                 *v.azimuthal.elements,
                 *v.longitudinal.elements,
-                *v.temporal.elements
+                *v.temporal.elements,
             ),
             returns,
             1,
